@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -33,20 +35,16 @@
 #include <set>
 #include <string>
 #include <string_view>
-#include <utility>
 #include <vector>
 
-#include "modules/adminapi/common/clone_options.h"
 #include "modules/adminapi/common/cluster_types.h"
 
 #include "modules/adminapi/common/metadata_management_mysql.h"
 #include "modules/mod_utils.h"
 #include "mysqlshdk/libs/config/config.h"
 #include "mysqlshdk/libs/db/connection_options.h"
-#include "mysqlshdk/libs/db/session.h"
 #include "mysqlshdk/libs/mysql/replication.h"
 #include "mysqlshdk/libs/utils/enumset.h"
-#include "scripting/lang_base.h"
 #include "scripting/types.h"
 
 namespace mysqlsh {
@@ -266,6 +264,7 @@ inline constexpr const char kUpdate[] = "update";
 inline constexpr const char kUpdateTopologyMode[] = "updateTopologyMode";
 inline constexpr const char kUpgradeCommProtocol[] = "upgradeCommProtocol";
 inline constexpr const char kUpdateViewChangeUuid[] = "updateViewChangeUuid";
+inline constexpr const char kRepairMetadata[] = "repairMetadata";
 inline constexpr const char kAll[] = "all";
 inline constexpr const char kTimeout[] = "timeout";
 inline constexpr const char kInvalidateErrorInstances[] =
