@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -27,7 +29,6 @@
 #include <list>
 #include <map>
 #include <memory>
-#include <optional>
 #include <set>
 #include <string>
 #include <utility>
@@ -37,7 +38,6 @@
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/instance_pool.h"
 #include "modules/adminapi/common/metadata_management_mysql.h"
-#include "mysqlshdk/libs/db/session.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/mysql/undo.h"
 #include "mysqlshdk/libs/mysql/utils.h"
@@ -212,6 +212,15 @@ class MetadataStorage {
    */
   void cleanup_for_cluster(Cluster_id cluster_id);
 
+  /**
+   * Deletes any dangling Clusters the ClusterSet's Metadata may have
+   *
+   * Ensures that any unrelated Cluster entries on the ClusterSet's Metadata are
+   * removed. Those can be resulting of failed actions, such as adding a new
+   * Replica Cluster.
+   */
+  void prune_clusterset_metadata(const Cluster_set_id &cs_id);
+
   Cluster_set_id create_cluster_set_record(
       Cluster_set_impl *cs, Cluster_id seed_cluster_id,
       shcore::Dictionary_t seed_attributes);
