@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -456,9 +458,38 @@ void password_prompt(Connection_options *options) {
 
 }  // namespace
 
+/**
+ * Password Retrieval Logic
+ *
+ * When attempting to create a connection the connection data will be taken from
+ * the following sources in order of precedence:
+ *
+ * 1) Options File
+ * 2) Login Path
+ * 3) Command line options
+ * 4) Stored Password
+ * 5) Interactive Password Prompt
+ *
+ * Connection Option Resolution
+ * ============================
+ * Fron 1 to 3 the last connection option found overrides earlier occurrences.
+ *
+ * In 3, the right-most option overrides any previous definition.
+ *
+ * 4 and 5 are specific to passwords and are used only if the password is not
+ * defined by any of the previous means.
+ *
+ *
+ * Disabling Elements
+ * ==================
+ * Usage of options file is disabled through --no-defaults
+ * Usage of Login Path is disabled through --no-login-paths
+ * Usage of Stored Passwords is disabled through -p
+ */
+
 std::shared_ptr<mysqlshdk::db::ISession> establish_session(
     const Connection_options &options, bool prompt_for_password,
-    bool prompt_in_loop) {
+    bool prompt_in_loop, bool enable_stored_passwords) {
   FI_SUPPRESS(mysql);
   FI_SUPPRESS(mysqlx);
 
@@ -472,7 +503,7 @@ std::shared_ptr<mysqlshdk::db::ISession> establish_session(
       mysqlshdk::ssh::current_ssh_manager()->create_tunnel(&ssh);
     }
 
-    if (!copy.has_password() && copy.has_user()) {
+    if (!copy.has_password() && copy.has_user() && enable_stored_passwords) {
       if (shcore::Credential_manager::get().get_password(&copy)) {
         try {
           return create_session(copy);
