@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2021, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2021, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -149,7 +151,7 @@ int libssh_auth_callback(const char *prompt, char *buf, size_t len, int echo,
   strncpy(buf, return_value.data(),
           return_value.size() > len ? len : return_value.size());
 
-  shcore::clear_buffer(&return_value);
+  shcore::clear_buffer(return_value);
   return 0;
 }
 }  // namespace
@@ -628,7 +630,7 @@ Ssh_auth_return Ssh_session::auth_password(
           throw shcore::cancelled("User cancelled");
       }
       config->set_password(passphrase);
-      shcore::clear_buffer(&passphrase);
+      shcore::clear_buffer(passphrase);
     }
   }
   if (config->has_password()) {
@@ -781,7 +783,7 @@ Ssh_auth_return Ssh_session::auth_interactive() {
       }
 
       shcore::on_leave_scope cleanup([&reply]() {
-        if (!reply.empty()) shcore::clear_buffer(&reply);
+        if (!reply.empty()) shcore::clear_buffer(reply);
       });
       try {
         if (m_session->userauthKbdintSetAnswer(i, reply.c_str()) == 0) {
