@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -65,10 +67,9 @@ void clear_buffer(char *buffer, size_t size) {
 #endif
 }
 
-void clear_buffer(std::string *buffer) {
-  assert(buffer);
-  clear_buffer(&(*buffer)[0], buffer->capacity());
-  buffer->clear();
+void clear_buffer(std::string &buffer) {
+  clear_buffer(buffer.data(), buffer.size());
+  buffer.clear();
 }
 
 std::string_view SHCORE_PUBLIC str_strip_view(std::string_view s,
