@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -2601,5 +2603,72 @@ TEST_F(Compatibility_test, replace_quoted_strings) {
          {"\"one\"", "'two'"});
 }
 
+TEST_F(Compatibility_test, parse_grant_statement) {
+  const auto EXPECT = [](const std::string &statement, bool expected_result,
+                         const Privilege_level_info &expected) {
+    SCOPED_TRACE(statement);
+
+    Privilege_level_info info;
+    ASSERT_EQ(expected_result, parse_grant_statement(statement, &info));
+
+    if (expected_result) {
+      EXPECT_EQ(expected.grant, info.grant);
+      EXPECT_EQ(expected.level, info.level);
+      EXPECT_EQ(expected.schema, info.schema);
+      EXPECT_EQ(expected.object, info.object);
+      EXPECT_EQ(expected.privileges, info.privileges);
+    }
+  };
+
+  {
+    Privilege_level_info info;
+    EXPECT_THROW(parse_grant_statement("CREATE ROLE IF NOT EXISTS r@l;", &info),
+                 std::runtime_error);
+  }
+
+  using Level = Privilege_level_info::Level;
+
+  EXPECT("GRANT SUPER ON *.* TO u@h", true,
+         {true, Level::GLOBAL, "*", "*", {"SUPER"}});
+  EXPECT("REVOKE CREATE TABLESPACE, CREATE USER, FILE ON *.* FROM u@h", true,
+         {false,
+          Level::GLOBAL,
+          "*",
+          "*",
+          {"CREATE TABLESPACE", "CREATE USER", "FILE"}});
+
+  EXPECT("GRANT EVENT, LOCK TABLES ON s.* TO u@h", true,
+         {true, Level::SCHEMA, "s", "*", {"EVENT", "LOCK TABLES"}});
+  EXPECT("REVOKE LOCK TABLES ON s.* FROM u@h", true,
+         {false, Level::SCHEMA, "s", "*", {"LOCK TABLES"}});
+
+  EXPECT("GRANT SELECT, SHOW VIEW, TRIGGER ON s.t TO u@h", true,
+         {true, Level::TABLE, "s", "t", {"SELECT", "SHOW VIEW", "TRIGGER"}});
+  EXPECT("REVOKE ALTER ON TABLE s.t FROM u@h", true,
+         {false, Level::TABLE, "s", "t", {"ALTER"}});
+  EXPECT("GRANT SELECT (c1), INSERT(c1, c2) ON s.t TO u@h", true,
+         {true, Level::TABLE, "s", "t", {"SELECT", "INSERT"}});
+
+  EXPECT("GRANT ALTER ROUTINE ON FUNCTION s.f TO u@h", true,
+         {true, Level::ROUTINE, "s", "f", {"ALTER ROUTINE"}});
+  EXPECT("GRANT ALTER rOUTINE ON s.f TO u@h", true,
+         {true, Level::ROUTINE, "s", "f", {"ALTER ROUTINE"}});
+  EXPECT("REVOKE EXECUTE ON PROCEDURE s.r FROM u@h", true,
+         {false, Level::ROUTINE, "s", "r", {"EXECUTE"}});
+
+  EXPECT("GRANT PROXY ON r TO u@h", false, {});
+  EXPECT("GRANT PROXY ON ''@'' TO u@h", false, {});
+
+  EXPECT("GRANT dev TO u@h", true, {true, Level::ROLE, "", "", {"dev"}});
+  EXPECT("REVOKE dev FROM u@h", true, {false, Level::ROLE, "", "", {"dev"}});
+
+  EXPECT("GRANT dev, admin@localhost TO u@h", true,
+         {true, Level::ROLE, "", "", {"dev", "admin@localhost"}});
+  EXPECT("REVOKE `admin`@`%`, dev FROM u@h", true,
+         {false, Level::ROLE, "", "", {"dev", "`admin`@`%`"}});
+
+  EXPECT("GRANT proxy TO u@h", true, {true, Level::ROLE, "", "", {"proxy"}});
+}
+
 }  // namespace compatibility
 }  // namespace mysqlsh
