@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -38,9 +40,9 @@ class Mock_mysql_shell : public mysqlsh::Mysql_shell {
                    shcore::Interpreter_delegate *custom_delegate)
       : mysqlsh::Mysql_shell(options, custom_delegate) {}
 
-  MOCK_METHOD3(connect,
-               std::shared_ptr<mysqlsh::ShellBaseSession>(
-                   const mysqlshdk::db::Connection_options &, bool, bool));
+  MOCK_METHOD4(connect, std::shared_ptr<mysqlsh::ShellBaseSession>(
+                            const mysqlshdk::db::Connection_options &, bool,
+                            bool, bool));
   MOCK_METHOD1(cmd_disconnect, bool(const std::vector<std::string> &args));
 };
 
@@ -286,11 +288,11 @@ TEST_F(mod_shell_test, parse_uri) {
 TEST_F(mod_shell_test, connect) {
   // ensure that shell.connect() calls Mysql_shell::connect()
 
-  EXPECT_CALL(*_backend, connect(_, false, true));
+  EXPECT_CALL(*_backend, connect(_, false, true, true));
 
   _shell->connect(mysqlshdk::db::Connection_options{_mysql_uri});
 
-  EXPECT_CALL(*_backend, connect(_, false, false));
+  EXPECT_CALL(*_backend, connect(_, false, false, true));
   _shell->open_session(mysqlshdk::db::Connection_options{_mysql_uri});
 }
 
